# testuda-probability

testuda-probability is a Python library submitted in accordance to request from the Udacity Machine Learning Engineer Nanodegree assignment. Please do not download without permission.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install testuda-probability
```

## Usage

```python
from testuda_probability import Gaussian, Binomial

gaussian = Gaussian(0, 1)
binomial = Binomial(0.4, 20)
print(gaussian)
>>> mean: 0 standard deviation: 1
print(binomial)
>>> mean: 8, standard deviation: 2.19, p 0.4, n 20
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)